@@ -95,7 +95,7 @@ class GourdSyncTcp(SocketServer.ThreadingTCPServer, CallBackMgr):
     logger = None
     debug = False
 
-    def __init__(self, log_name=None, backlog=None, terminator=None, request_handler_class=None):
+    def __init__(self, logger_name=None, backlog=None, terminator=None, request_handler_class=None):
         SocketServer.ThreadingTCPServer.__init__(self,
                                                  (None, None),
                                                  request_handler_class or GourdSyncTcpRequestHandler,
@@ -103,7 +103,7 @@ class GourdSyncTcp(SocketServer.ThreadingTCPServer, CallBackMgr):
         CallBackMgr.__init__(self)
 
         self.terminator = terminator or constants.TERMINATOR
-        self.logger = logging.getLogger(log_name or constants.LOG_NAME)
+        self.logger = logging.getLogger(logger_name or constants.LOGGER_NAME)
         # 就是用的backlog，默认是5
         self.request_queue_size = backlog or constants.BACKLOG
 
@@ -172,13 +172,13 @@ class GourdSyncUdp(SocketServer.ThreadingUDPServer, CallBackMgr):
     logger = None
     debug = False
 
-    def __init__(self, log_name=None, request_handler_class=None):
+    def __init__(self, logger_name=None, request_handler_class=None):
         SocketServer.ThreadingUDPServer.__init__(self,
                                                  (None, None),
                                                  request_handler_class or GourdSyncUdpRequestHandler,
                                                  bind_and_activate=False)
         CallBackMgr.__init__(self)
-        self.logger = logging.getLogger(log_name or constants.LOG_NAME)
+        self.logger = logging.getLogger(logger_name or constants.LOGGER_NAME)
 
     def run(self, host, port):
         self.server_address = (host, port)
